'use strict';
var yeoman = require('yeoman-generator'),
  chalk = require('chalk'),
  yosay = require('yosay'),
  _ = require('lodash');

module.exports = yeoman.generators.Base.extend({
  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome!'
    ));

    var prompts = [{
      type: 'input',
      name: 'projectName',
      message: 'Project name: ',
      default: 'jd-react'
    },
    {
      type: 'input',
      name: 'description',
      message: 'Short description: ',
      default: ''
    }];

    this.prompt(prompts, function (props) {
      this.props = props;
      done();
    }.bind(this));
  },

  writing: {
    app: function () {
      this.fs.copyTpl(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json'),
        {
          projectName: _.kebabCase(this.props.projectName),
          description: this.props.description
        }
      );
      this.fs.copyTpl(
        this.templatePath('_package.json'),
        this.destinationPath('package.json'),
        {
          projectName: _.kebabCase(this.props.projectName),
          description: this.props.description
        }
      );
      this.fs.copy(
        this.templatePath('_gulpfile.js'),
        this.destinationPath('gulpfile.js')
      );
      this.fs.copy(
        this.templatePath('_config.js'),
        this.destinationPath('config.js')
      );
      this.fs.copy(
        this.templatePath('src/**/**/*.*'),
        this.destinationPath('src')
      );
      this.fs.copy(
        this.templatePath('src/**/**/*'),
        this.destinationPath('src')
      );
      this.fs.copy(
        this.templatePath('src/**/**/.*'),
        this.destinationPath('src')
      );
    },

    projectfiles: function () {
      this.fs.copy(
        this.templatePath('gitignore'),
        this.destinationPath('.gitignore')
      );
      this.fs.copy(
        this.templatePath('eslintrc'),
        this.destinationPath('.eslintrc')
      );
      this.fs.copy(
        this.templatePath('README.md'),
        this.destinationPath('README.md')
      );
    }
  },

  install: function () {
    this.installDependencies();
  }
});
